@@ -1,3 +1,6 @@
+"""Functions implementing command line executables"""
+
+
 def nextsong():
     import argparse
     from nextsong.config import get as get_cfg
@@ -38,6 +41,7 @@ def nextsong():
     parser.add_argument(
         "-n",
         "--new-state",
+        action="store_true",
         help="start playlist over, ignoring existing state file [%(default)s]",
         default=get_cfg("new_state"),
     )
@@ -53,13 +57,17 @@ def nextsong():
         state_path=args.state,
         new_state=args.new_state,
     ):
-        # TODO: ask forgiveness, not permission
-        if not get_cfg("new_state") and Path(get_cfg("state_path")).exists():
-            with open(get_cfg("state_path"), "rb") as f:
-                state = pickle.load(f)
-        else:
+        state = None
+        if not get_cfg("new_state"):
+            try:
+                with open(get_cfg("state_path"), "rb") as f:
+                    state = pickle.load(f)
+            except FileNotFoundError:
+                pass
+        if state is None:
             playlist = nextsong.playlist.Playlist.load_xml()
             state = iter(playlist)
+
         try:
             media = next(state)
         except StopIteration:
